@@ -171,7 +171,11 @@ def display_image_responses(
                     if a.get("ai_refused", False)
                     else exclusion_caption
                     if a.get("exclude_from_scoring", False)
-                    else f"{'Pass' if a.get('is_passed') else 'Fail'} ({a.get('confidence'):.1%} confidence): {a.get('explanation')}"
+                    else (
+                        f"{'Pass' if a.get('is_passed') else 'Fail'} "
+                        f"({a.get('confidence', 0):.1%} confidence): "
+                        f"{a.get('explanation') or ''}"
+                    )
                     for q in prompts
                     if q.prompt_uuid == a.get("prompt_uuid")
                 )
